@@ -863,9 +863,7 @@ class AutoscalingClient(AbstractClient):
         """This API is used to remove CVM instances from a scaling group. Instances removed via this API will not be terminated.
         * If the number of remaining `IN_SERVICE` instances in the scaling group is less than the minimum capacity, this API will return an error.
         * However, if the scaling group is in `DISABLED` status, the removal will not verify the relationship between the number of `IN_SERVICE` instances and the minimum capacity.
-
-        The CVM will be associated from the CLB instance (if any).
-
+        * This removal will unassociate the CVM from the CLB instance that has been configured for the scaling group.
 
         :param request: Request instance for DetachInstances.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.DetachInstancesRequest`
@@ -1214,9 +1212,7 @@ class AutoscalingClient(AbstractClient):
         """This API is used to delete CVM instances from a scaling group. Instances that are automatically created through AS will be terminated, while those manually added to the scaling group will be removed and retained.
         * If the number of remaining `IN_SERVICE` instances in the scaling group is less than the minimum capacity, this API will return an error.
         * However, if the scaling group is in `DISABLED` status, the removal will not verify the relationship between the number of `IN_SERVICE` instances and the minimum capacity.
-
-        This removal will unassociate the CVM from the CLB instance that has been configured for the scaling group.
-
+        * This removal will unassociate the CVM from the CLB instance that has been configured for the scaling group.
 
         :param request: Request instance for RemoveInstances.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.RemoveInstancesRequest`
@@ -1243,6 +1239,70 @@ class AutoscalingClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ScaleInInstances(self, request):
+        """This API is used to reduce the specified number of instances from the scaling group, which returns the scaling activity ID `ActivityId`.
+        * The scaling group is not active.
+        * The scale-in instances will be selected according to the `TerminationPolicies` policy as described in [Reducing Capacity](https://intl.cloud.tencent.com/document/product/377/8563?from_cn_redirect=1).
+        * Only the `IN_SERVICE` instances will be reduced. To reduce instances in other statues, use the [`DetachInstances`](https://intl.cloud.tencent.com/document/api/377/20436?from_cn_redirect=1) or [`RemoveInstances`](https://intl.cloud.tencent.com/document/api/377/20431?from_cn_redirect=1) API.
+        * The desired capacity will be reduced accordingly. The new desired capacity should be no less than the minimum capacity.
+        * If the scale-in activity failed or partially succeeded, the final desired capacity only deducts the instances that have been reduced successfully.
+
+        :param request: Request instance for ScaleInInstances.
+        :type request: :class:`tencentcloud.autoscaling.v20180419.models.ScaleInInstancesRequest`
+        :rtype: :class:`tencentcloud.autoscaling.v20180419.models.ScaleInInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ScaleInInstances", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ScaleInInstancesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ScaleOutInstances(self, request):
+        """This API is used to add the specified number of instances to the scaling group, which returns the scaling activity ID `ActivityId`.
+        * The scaling group is not active.
+        * The desired capacity will be increased accordingly. The new desired capacity should be no more than the maximum capacity.
+        * If the scale-out activity failed or partially succeeded, the final desired capacity only includes the instances that have been added successfully.
+
+        :param request: Request instance for ScaleOutInstances.
+        :type request: :class:`tencentcloud.autoscaling.v20180419.models.ScaleOutInstancesRequest`
+        :rtype: :class:`tencentcloud.autoscaling.v20180419.models.ScaleOutInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ScaleOutInstances", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ScaleOutInstancesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SetInstancesProtection(self, request):
         """This API (SetInstancesProtection) is used to enable scale-in protection for an instance.
         When an instance has scale-in protection enabled, it will not be removed when scaling is triggered by replacement of unhealthy instances, alarm trigger policy, threshold change, etc.
